#!/bin/bash

#
# In a multi xen host environment this wrapper checks before creating a new
# xen domain if it is surely not running on another xen host.
#
# The xen hosts must be configured in /etc/xen/hosts (one hostname or ip
# address per line) and must be reachable over ssh.
#

# xm program
XM="/usr/sbin/xm"

# if first command is create and /etc/xen/hosts exists do our checks
if [ "$1" = "create" ] && [ -s "/etc/xen/hosts" ]
then
	# get config file
	if [ -s "$2" ]
	then
		CONFIG="$2"
	elif [ -s "/etc/xen/$2" ]
	then
		CONFIG="/etc/xen/$2"
	else
		echo "Error: Unable to open config file: $2"
		exit 1
	fi
	# get xen domain name out of config file to variable DOMNAME
	unset "DOMNAME"
	eval "$(grep '^name' "$CONFIG" | sed s/'^name *= *'/'DOMNAME='/g)"
	if [ -z "$DOMNAME" ]
	then
		echo "Error: Unable to get name out of config file $CONFIG"
		exit 1
	fi
	# check each xen host
	for XENHOST in $(cat "/etc/xen/hosts")
	do
		if ! ssh $XENHOST "! $XM domid '$DOMNAME'" > /dev/null 2>&1
		then
			echo "Error: $DOMNAME ($CONFIG) seems to be running on $XENHOST"
			exit 1
		fi
	done
	# execute
	$XM "$@"
else
	# execute without checks
	$XM "$@"
fi
